@@ -19,16 +19,16 @@
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
   02111-1307, USA.
 
-  Copyright  2002-2004 Jan-ke Larsson
+  Copyright (C) 2002-2004 Jan-ke Larsson
 
 ************************************************************************/
 
 #include "dvipng.h"
 
-//#define NO_DRIFT
+/* #define NO_DRIFT */
 
 #ifdef DEBUG
-#include <ctype.h> // isprint
+#include <ctype.h> /* isprint */
 #endif
 
 struct stack_entry {  
@@ -268,7 +268,7 @@ void DrawCommand(unsigned char* command, void* parent /* dvi/vf */)
   case XXX1: case XXX2: case XXX3: case XXX4:
     DEBUG_PRINT(DEBUG_DVI,(" %d",
 		 UNumRead(command+1, dvi_commandlength[*command]-1)));
-    SetSpecial(command + dvi_commandlength[*command], 
+    SetSpecial((char*)command + dvi_commandlength[*command], 
 	       UNumRead(command+1, dvi_commandlength[*command]-1),
 	       hh,vv);
     break;
