@@ -42,18 +42,6 @@
 
 #ifdef HAVE_INTTYPES_H
 #  include <inttypes.h>
-#  ifndef HAVE_INT64_T
-/* Sometimes we want to use gcc -ansi -pedantic as a portability test
- * The typedef of int64_t is not in the system header file in that
- * case. Then, define int64_t as "long long" here. "long long" is
- * non-ansi, but is present in most modern compilers */
-#    ifdef HAVE_LONG_LONG
-typedef long long                int64_t;
-typedef unsigned long long      uint64_t;
-#    else
-#      error Your system lacks 64-bit integer types
-#    endif
-#  endif
 #else /* HAVE_INTTYPES_H */
 typedef signed char               int8_t;
 typedef unsigned char            uint8_t;
@@ -65,7 +53,6 @@ typedef long long                int64_t;
 typedef unsigned long long      uint64_t;
 #endif /* HAVE_INTTYPES_H */
 
-
 #ifndef INT32_MIN
 #define INT32_MIN   (-2147483647-1)
 #endif
