@@ -19,7 +19,7 @@
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
   02111-1307, USA.
 
-  Copyright  2002-2004 Jan-ke Larsson
+  Copyright (C) 2002-2004 Jan-ke Larsson
 
 ************************************************************************/
 
@@ -33,7 +33,7 @@ void LoadFT(int32_t c, struct char_entry * ptr)
   FT_Bitmap  bitmap;
   FT_UInt    glyph_i;
   int i,j,k;
-  char* bit;
+  unsigned char* bit;
 
   DEBUG_PRINT(DEBUG_FT,("\n  LOAD FT CHAR\t%d (%d)",c,ptr->tfmw));
   if (currentfont->psfontmap!=NULL
@@ -52,8 +52,7 @@ void LoadFT(int32_t c, struct char_entry * ptr)
   bitmap=currentfont->face->glyph->bitmap;
   DEBUG_PRINT(DEBUG_FT,(" (%dx%d)",bitmap.width,bitmap.rows));
     
-  if ((ptr->data 
-       = (char*) calloc(bitmap.width*bitmap.rows,sizeof(char))) == NULL)
+  if ((ptr->data = calloc(bitmap.width*bitmap.rows,sizeof(char))) == NULL)
     Fatal("Unable to allocate image space for char <%c>\n", (char)c);
   ptr->w = bitmap.width;
   ptr->h = bitmap.rows;
@@ -64,8 +63,8 @@ void LoadFT(int32_t c, struct char_entry * ptr)
   for(i=0;i<bitmap.rows;i++) {
     for(j=0;j<bitmap.width;j++) {
       k=bitmap.buffer[i*bitmap.pitch+j]/(256/GREYLEVELS)*17;
-      //k=(bitmap.buffer[i*bitmap.pitch+j]+1)/16;
-      //k= k>0 ? k*16-1 : 0;
+      /* k=(bitmap.buffer[i*bitmap.pitch+j]+1)/16; */
+      /* k= k>0 ? k*16-1 : 0; */
       DEBUG_PRINT(DEBUG_GLYPH,("%3u ",k));
       bit[i*bitmap.width+j]=k;
     }
