@@ -46,16 +46,23 @@ bool DecodeArgs(int argc, char ** argv)
   char *dviname=NULL;        /* Name of dvi file               */
   char *outname=NULL;        /* Name of output file            */
 
+  if (argv[0]) {
 #ifdef HAVE_GDIMAGEGIF
-  programname=strrchr(argv[0],'/');
-  if (programname!=NULL)
-    programname++;
-  else
-    programname=argv[0];
-  if (strncmp(programname,"dvigif",6)==0)
-    flags |= GIF_OUTPUT;
+    programname=strrchr(argv[0],'/');
+    if (programname!=NULL)
+      programname++;
+    else
+      programname=argv[0];
+    if (strncmp(programname,"dvigif",6)==0)
+      flags |= GIF_OUTPUT;
 #endif
-  programname=argv[0];
+    programname=argv[0];
+    Message(BE_NONQUIET,"This is %s",programname);
+    if (strcmp(basename(programname),PACKAGE_NAME)!=0)
+      Message(BE_NONQUIET," (%s)", PACKAGE_NAME);
+    Message(BE_NONQUIET," %s Copyright 2002-2004 Jan-ke Larsson\n",
+	    PACKAGE_VERSION);
+  }
 
   for (i=1; i<argc; i++) {
     if (*argv[i]=='-') {
@@ -499,14 +506,6 @@ named COPYING and dvipng.c.");
       dviname=argv[i];
     }
   }
-
-  if (programname) {
-    Message(BE_NONQUIET,"This is %s",programname);
-    if (strcmp(basename(programname),PACKAGE_NAME)!=0)
-      Message(BE_NONQUIET," (%s)", PACKAGE_NAME);
-    Message(BE_NONQUIET," %s Copyright 2002-2004 Jan-ke Larsson\n",
-	    PACKAGE_VERSION);
-  }
   if (dviname != NULL) {
     if (dvi != NULL && dvi->filep != NULL) 
       DVIClose(dvi);
@@ -714,6 +713,7 @@ bool MmapFile (char *filename,struct filemmap *fmmap)
   }
   fstat(fmmap->fd,&stat);
   fmmap->size=stat.st_size;
+# ifdef HAVE_MMAP
   fmmap->mmap = mmap(NULL,fmmap->size, PROT_READ, MAP_SHARED,fmmap->fd,0);
   if (fmmap->mmap == (char*)-1) {
     Warning("cannot mmap file <%s>",filename);
@@ -721,6 +721,17 @@ bool MmapFile (char *filename,struct filemmap *fmmap)
     close(fmmap->fd);
     return(true);
   }
+# else /* HAVE_MMAP */
+  fmmap->mmap = malloc(fmmap->size);
+  if (read(fmmap->fd,fmmap->mmap,fmmap->size)<fmmap->size) {
+    Warning("too little data in <%s>",filename);
+    free(fmmap->mmap);
+    fmmap->mmap=NULL;
+    close(fmmap->fd);
+    return(true);
+  }
+  close(fmmap->fd);
+# endif /* HAVE_MMAP */
 #else /* MIKTEX */
   fmmap->hFile = CreateFile(filename, GENERIC_READ, 0, 0, OPEN_EXISTING,
 			    FILE_FLAG_RANDOM_ACCESS, 0);
@@ -750,10 +761,14 @@ void UnMmapFile(struct filemmap* fmmap)
 {
   if (fmmap->mmap!=NULL) {
 #ifndef MIKTEX
+# ifdef HAVE_MMAP
     if (munmap(fmmap->mmap,fmmap->size))
       Warning("cannot munmap file at 0x%X",fmmap->mmap);
     if (close(fmmap->fd))
       Warning("cannot close file descriptor %d",fmmap->fd);
+# else /* HAVE_MMAP */
+    free(fmmap->mmap);
+# endif /* HAVE_MMAP */
 #else  /* MIKTEX */
     UnmapViewOfFile (fmmap->mmap);
     CloseHandle (fmmap->hMap);
