@@ -19,7 +19,7 @@
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
   02111-1307, USA.
 
-  Copyright  2002-2004 Jan-ke Larsson
+  Copyright (C) 2002-2004 Jan-ke Larsson
 
 ************************************************************************/
 
@@ -47,7 +47,7 @@ ps2png(const char *psfile, int hresolution, int vresolution,
 #endif
   FILE *psstream=NULL, *pngstream=NULL;
   char resolution[STRSIZE]; 
-  //  char devicesize[STRSIZE]; 
+  /*   char devicesize[STRSIZE];  */
   /* For some reason, png256 gives inferior result */
   char *device="-sDEVICE=png16m";  
   gdImagePtr psimage=NULL;
@@ -79,16 +79,16 @@ ps2png(const char *psfile, int hresolution, int vresolution,
 #ifdef DEBUG
     if (flags & NO_GSSAFER) {
       DEBUG_PRINT(DEBUG_GS,
-		  ("\n  GS CALL:\t%s %s %s %s %s %s %s %s %s %s ",// %s",
-		   GS_PATH, device, resolution, //devicesize,
+		  ("\n  GS CALL:\t%s %s %s %s %s %s %s %s %s %s ",/* %s", */
+		   GS_PATH, device, resolution, /* devicesize, */
 		   "-dBATCH", "-dNOPAUSE", "-q", 
 		   "-sOutputFile=-", 
 		   "-dTextAlphaBits=4", "-dGraphicsAlphaBits=4",
 		   "-"));
     } else {
       DEBUG_PRINT(DEBUG_GS,
-		  ("\n  GS CALL:\t%s %s %s %s %s %s %s %s %s %s %s ",// %s",
-		   GS_PATH, device, resolution, //devicesize,
+		  ("\n  GS CALL:\t%s %s %s %s %s %s %s %s %s %s %s ",/* %s", */
+		   GS_PATH, device, resolution, /*devicesize,*/
 		   "-dBATCH", "-dNOPAUSE", "-dSAFER", "-q", 
 		   "-sOutputFile=-", 
 		   "-dTextAlphaBits=4", "-dGraphicsAlphaBits=4",
@@ -99,13 +99,13 @@ ps2png(const char *psfile, int hresolution, int vresolution,
     dup2(uppipe[1], STDOUT_FILENO);
     close(uppipe[1]);
     if (flags & NO_GSSAFER) 
-      execl (GS_PATH, GS_PATH, device, resolution, //devicesize,
+      execl (GS_PATH, GS_PATH, device, resolution, /*devicesize,*/
 	     "-dBATCH", "-dNOPAUSE", "-q", 
 	     "-sOutputFile=-", 
 	     "-dTextAlphaBits=4", "-dGraphicsAlphaBits=4",
 	     "-",NULL);
     else
-      execl (GS_PATH, GS_PATH, device, resolution, //devicesize,
+      execl (GS_PATH, GS_PATH, device, resolution, /*devicesize,*/
 	     "-dBATCH", "-dNOPAUSE", "-dSAFER", "-q", 
 	     "-sOutputFile=-", 
 	     "-dTextAlphaBits=4", "-dGraphicsAlphaBits=4",
@@ -129,28 +129,28 @@ ps2png(const char *psfile, int hresolution, int vresolution,
   }
   if (flags & NO_GSSAFER) {
     DEBUG_PRINT(DEBUG_GS,
-		("\n  GS CALL:\t%s %s %s %s %s %s %s %s %s %s ",// %s",
-		 szGsPath, device, resolution, //devicesize,
+		("\n  GS CALL:\t%s %s %s %s %s %s %s %s %s %s ",/* %s",*/
+		 szGsPath, device, resolution, /*devicesize,*/
 		 "-dBATCH", "-dNOPAUSE", "-q", 
 		 "-sOutputFile=-", 
 		 "-dTextAlphaBits=4", "-dGraphicsAlphaBits=4",
 		 "-"));
-    sprintf(szCommandLine,"\"%s\" %s %s %s %s %s %s %s %s %s",// %s",
-	    szGsPath, device, resolution, //devicesize,
+    sprintf(szCommandLine,"\"%s\" %s %s %s %s %s %s %s %s %s",/* %s",*/
+	    szGsPath, device, resolution, /*devicesize,*/
 	    "-dBATCH", "-dNOPAUSE", "-q", 
 	    "-sOutputFile=-", 
 	    "-dTextAlphaBits=4", "-dGraphicsAlphaBits=4",
 	    "-");
   } else {
     DEBUG_PRINT(DEBUG_GS,
-		("\n  GS CALL:\t%s %s %s %s %s %s %s %s %s %s %s ",// %s",
-		 szGsPath, device, resolution, //devicesize,
+		("\n  GS CALL:\t%s %s %s %s %s %s %s %s %s %s %s ",/* %s",*/
+		 szGsPath, device, resolution, /*devicesize,*/
 		 "-dBATCH", "-dNOPAUSE", "-dSAFER", "-q", 
 		 "-sOutputFile=-", 
 		 "-dTextAlphaBits=4", "-dGraphicsAlphaBits=4",
 		 "-"));
-    sprintf(szCommandLine,"\"%s\" %s %s %s %s %s %s %s %s %s %s",// %s",
-	    szGsPath, device, resolution, //devicesize,
+    sprintf(szCommandLine,"\"%s\" %s %s %s %s %s %s %s %s %s %s",/* %s",*/
+	    szGsPath, device, resolution, /*devicesize,*/
 	    "-dBATCH", "-dNOPAUSE", "-dSAFER", "-q", 
 	    "-sOutputFile=-", 
 	    "-dTextAlphaBits=4", "-dGraphicsAlphaBits=4",
